#!/bin/bash
MYPATH=$(cd $(dirname "$0"); pwd)
cd ../../..
#
## clean up
#
cleanup() {
    local _dsa=$1
    rm -f "$_dsa".db
    rm -f "$_dsa".db.gz
    rm -f "$_dsa".db.bz2
    export OPT=-i
    bash dsas/delete.sh "$_dsa" delete_db_all
    export OPT=
    }

JSON=$$.json
NAME=dsa$$
HOST=$(hostname)
PORT=60000
bash "$MYPATH"/user.temp "$NAME" "$HOST" "$PORT" > "$JSON"
EXIST=$(bash dsas/create.sh "$JSON")
EXIST=$(bash dsas/exist.sh "$NAME"); STATUS=$?
if [[ "$STATUS" -ne 0 ]] ; then
    >&2 echo "DSA $NAME creation failed, tests stopped"
    exit 1
else
    >&2 echo "DSA $NAME created"
    echo "$EXIST" |
        ./jq '{ "name": .name, "status": .status, "console-port": .config.knowledge[0]."console-port" }'
fi
bash dsas/status/stop.sh "$NAME"
bash dsas/ldif/load.sh "$NAME" "${MYPATH}/user.ldif"
bash dsas/ldif/read.sh "$NAME"
bash dsas/status/start.sh "$NAME"
bash dsas/onlinebackups/create.sh "$NAME"
STATUS=
>&2 echo $NAME waiting for onlinebackup to be ready 
while [[ "$STATUS" != "ready" ]] ; do
    STATUS=$(bash dsas/onlinebackups/status.sh "$NAME" | ./jq -r '.status')
    echo "$STATUS" ...
    sleep 1
done
bash dsas/status/stop.sh "$NAME"
#
## download
#
rm -f "$NAME".db
>&2 echo "$NAME downloading db ..."
bash "${MYPATH}/../download.sh" "$NAME" "" db
if [ ! -f "$NAME".db ] ; then
    >&2 echo "$NAME download db failed."
    cleanup "$NAME"
    exit 1
fi 
rm -f "$NAME".db.gz
>&2 echo "$NAME downloading default db.gz ..."
bash "${MYPATH}/../download.sh" "$NAME"
if [ ! -f "$NAME".db.gz ] ; then
    >&2 echo "$NAME download default db.gz failed."
    cleanup "$NAME"
    exit 1
fi 
rm -f "$NAME".db.gz
>&2 echo "$NAME downloading db.gz ..."
bash "${MYPATH}/../download.sh" "$NAME" "" gzip
if [ ! -f "$NAME".db.gz ] ; then
    >&2 echo "$NAME download db.gz failed."
    cleanup "$NAME"
    exit 1
fi 
rm -f "$NAME".db.bz2
>&2 echo "$NAME downloading db.bz2 ..."
bash "${MYPATH}/../download.sh" "$NAME" "" bzip2
if [ ! -f "$NAME".db.bz2 ] ; then
    >&2 echo "$NAME download db.bz2 failed."
    cleanup "$NAME"
    exit 1
fi 
#
## delete.sh
#
bash "$MYPATH"/../delete.sh "$NAME"
>&2 echo "after delete, expecting error ..."
bash dsas/ldif/read.sh "$NAME"
#
## restore from backup
#
bash "$MYPATH"/../restore.sh "$NAME"
>&2 echo "after restoration, ..."
bash dsas/ldif/read.sh "$NAME"
#
## empty.sh
#
bash "$MYPATH"/../empty.sh "$NAME"
>&2 echo "after empty, expecting no content w/o error ..."
bash dsas/ldif/read.sh "$NAME"
#
## loading
#
>&2 echo "loading db ..."
bash "${MYPATH}/../load.sh" "$NAME" "$NAME".db db
>&2 echo "after loading db ..."
bash dsas/ldif/read.sh "$NAME"
>&2 echo "empty db ..."
bash "$MYPATH"/../empty.sh "$NAME"
>&2 echo "after empty ..."
bash dsas/ldif/read.sh "$NAME"
rm "$NAME".db
>&2 echo "loading db.gz ..."
bash "${MYPATH}/../load.sh" "$NAME" "$NAME".db.gz gzip
>&2 echo "after loading db.gz ..."
bash dsas/ldif/read.sh "$NAME"
>&2 echo "empty db ..."
bash "$MYPATH"/../empty.sh "$NAME"
>&2 echo "after empty ..."
bash dsas/ldif/read.sh "$NAME"
rm "$NAME".db.gz
>&2 echo "loading db.bz2 ..."
bash "${MYPATH}/../load.sh" "$NAME" "$NAME".db.bz2 bzip2
>&2 echo "after loading db.bz2 ..."
bash dsas/ldif/read.sh "$NAME"
>&2 echo "empty db ..."
bash "$MYPATH"/../empty.sh "$NAME"
>&2 echo "after empty ..."
bash dsas/ldif/read.sh "$NAME"
rm "$NAME".db.bz2
#
## clean up
#
cleanup "$NAME"
