#!/bin/bash
MYPATH=$(cd $(dirname "$0"); pwd)
cd ../../../..
#
## clean up
#
cleanup() {
    local _dsa=$1
    rm -f "$_dsa".ldif
    rm -f "$_dsa".ldif.gz
    rm -f "$_dsa".ldif.bz2
    export OPT=-i
    bash dsas/delete.sh "$_dsa" delete_db_all
    export OPT=
    }

JSON=$$.json
NAME=dsa$$
HOST=$(hostname)
PORT=60000
bash "$MYPATH"/user.temp "$NAME" "$HOST" "$PORT" > "$JSON"
EXIST=$(bash dsas/create.sh "$JSON")
EXIST=$(bash dsas/exist.sh "$NAME"); STATUS=$?
if [[ "$STATUS" -ne 0 ]] ; then
    >&2 echo "DSA $NAME creation failed, tests stopped"
    exit 1
else
    >&2 echo "DSA $NAME created"
    echo "$EXIST" |
        ./jq '{ "name": .name, "status": .status }'
fi
bash dsas/status/stop.sh "$NAME"
bash dsas/ldif/load.sh "$NAME" "${MYPATH}/user.ldif"
bash dsas/ldif/read.sh "$NAME"
bash dsas/status/start.sh "$NAME"
bash dsas/onlinebackups/create.sh "$NAME"
STATUS=
>&2 echo $NAME waiting for onlinebackup to be ready 
while [[ "$STATUS" != "ready" ]] ; do
    STATUS=$(bash dsas/onlinebackups/status.sh "$NAME" | ./jq -r '.status')
    echo "$STATUS" ...
    sleep 1
done
#
## download
#
rm -f "$NAME".ldif
>&2 echo "$NAME downloading ldif ..."
bash "${MYPATH}/../download.sh" "$NAME" "" ldif
if [ ! -f "$NAME".ldif ] ; then
    >&2 echo "$NAME download ldif failed."
    cleanup "$NAME"
    exit 1
fi 
rm -f "$NAME".ldif.gz
>&2 echo "$NAME downloading default ldif.gz ..."
bash "${MYPATH}/../download.sh" "$NAME"
if [ ! -f "$NAME".ldif.gz ] ; then
    >&2 echo "$NAME download default ldif.gz failed."
    cleanup "$NAME"
    exit 1
fi 
rm -f "$NAME".ldif.gz
>&2 echo "$NAME downloading ldif.gz ..."
bash "${MYPATH}/../download.sh" "$NAME" "" gzip
if [ ! -f "$NAME".ldif.gz ] ; then
    >&2 echo "$NAME download ldif.gz failed."
    cleanup "$NAME"
    exit 1
fi 
rm -f "$NAME".ldif.bz2
>&2 echo "$NAME downloading ldif.bz2 ..."
bash "${MYPATH}/../download.sh" "$NAME" "" bzip2
if [ ! -f "$NAME".ldif.bz2 ] ; then
    >&2 echo "$NAME download ldif.bz2 failed."
    cleanup "$NAME"
    exit 1
fi 
#
## clean up
#
cleanup "$NAME"
