#!/bin/bash
MYPATH=$(cd $(dirname "$0"); pwd)
cd ../../..
#
## clean up
#
cleanup() {
    local _dsa=$1
    >&2 echo "cleaning up $_dsa"
    rm -f "$_dsa".zdb.gz
    export OPT=-i
    bash dsas/delete.sh "$_dsa" delete_db_all
    export OPT=
    }

#
## waitForReady
#
waitForReady() {
    local _name=$1
    local _status=
    local >&2 echo $_name waiting for onlinebackup to be ready 
    while [[ "$_status" != "ready" ]] ; do
        _status=$(bash "${MYPATH}/../status.sh" "$NAME" | ./jq -r '.status')
        >&2 echo "$_status" ...
        sleep 1
    done
    }

JSON=$$.json
NAME=dsa$$
HOST=$(hostname)
PORT=60000
bash "$MYPATH"/user.temp "$NAME" "$HOST" "$PORT" > "$JSON"
EXIST=$(bash dsas/create.sh "$JSON")
EXIST=$(bash dsas/exist.sh "$NAME"); STATUS=$?
if [[ "$STATUS" -ne 0 ]] ; then
    >&2 echo "DSA $NAME creation failed, tests stopped"
    exit 1
else
    >&2 echo "DSA $NAME created"
    echo "$EXIST" |
        ./jq '{ "name": .name, "status": .status }'
fi
bash dsas/status/stop.sh "$NAME"
bash dsas/ldif/load.sh "$NAME" "${MYPATH}/user.ldif"
bash dsas/ldif/read.sh "$NAME"
bash dsas/status/start.sh "$NAME"
bash "${MYPATH}/../create.sh" "$NAME"
waitForReady "$NAME"
rm -f "$NAME".zdb.gz
bash "${MYPATH}/../download.sh" "$NAME"
if [ ! -f "$NAME".zdb.gz ] ; then
    >&2 echo "$NAME.zdb.gz download failed, tests stopped"
    cleanup "$NAME"
    exit 1
else
    >&2 echo "$NAME.zdb.gz downloaded"
    ls -l "$NAME.zdb.gz"
fi
bash dsas/status/stop.sh "$NAME"
bash dsas/db/empty.sh "$NAME"
>&2 echo after $NAME is emptied and ldif read
bash dsas/ldif/read.sh "$NAME"
bash dsas/status/start.sh "$NAME"
>&2 echo after $NAME is restarted and onlinebackup read
bash "${MYPATH}/../read.sh" "$NAME"
bash dsas/status/stop.sh "$NAME"
bash "${MYPATH}/../restore.sh" "$NAME"
>&2 echo after $NAME is restored from onlinebackup and ldif read
bash dsas/ldif/read.sh "$NAME"
bash "${MYPATH}/../delete.sh" "$NAME"
>&2 echo "$NAME after deletion of the onlinebackup"
bash "${MYPATH}/../status.sh" "$NAME"
cleanup "$NAME"
